
# Type: class_definition_apply_to




URI: [meta:class_definition_apply_to](https://w3id.org/biolink/biolinkml/meta/class_definition_apply_to)


## Domain and Range

[ClassDefinition](ClassDefinition.md) ->  <sub>0..*</sub> [ClassDefinition](ClassDefinition.md)

## Parents

 *  is_a: [apply_to](apply_to.md)

## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
